==> file-roller_0.8.orig.tar.gz: file-roller-0.8.orig/src/fr-command-zip.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  File-Roller
 *
 *  Copyright (C) 2001 The Free Software Foundation, Inc.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
 */

#ifndef FR_COMMAND_ZIP_H
#define FR_COMMAND_ZIP_H


#include <gtk/gtk.h>
#include "fr-command.h"
#include "fr-process.h"


#define FR_COMMAND_ZIP_TYPE        fr_command_zip_get_type ()
#define FR_COMMAND_ZIP(o)          GTK_CHECK_CAST (o, FR_COMMAND_ZIP_TYPE, FRCommandZip)
#define FR_COMMAND_ZIP_CLASS(k)    GTK_CHECK_CLASS_CAST (k, FR_COMMAND_ZIP_TYPE, FRCommandZipClass)
#define IS_FR_COMMAND_ZIP(o)       GTK_CHECK_TYPE (o, FR_COMMAND_ZIP_TYPE)


typedef struct _FRCommandZip       FRCommandZip;
typedef struct _FRCommandZipClass  FRCommandZipClass;


struct _FRCommandZip
{
	FRCommand  __parent;
	gboolean is_empty;
};


struct _FRCommandZipClass
{
	FRCommandClass __parent_class;
};


GtkType      fr_command_zip_get_type        (void);

FRCommand*   fr_command_zip_new             (FRProcess *process,
					     char *filename);


#endif /* FR_COMMAND_ZIP_H */

==> file-roller-2.12.0.tar.gz: file-roller-2.12.0/src/fr-command-zip.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  File-Roller
 *
 *  Copyright (C) 2001 The Free Software Foundation, Inc.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
 */

#ifndef FR_COMMAND_ZIP_H
#define FR_COMMAND_ZIP_H

#include <glib.h>
#include "fr-command.h"
#include "fr-process.h"

#define FR_TYPE_COMMAND_ZIP            (fr_command_zip_get_type ())
#define FR_COMMAND_ZIP(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), FR_TYPE_COMMAND_ZIP, FRCommandZip))
#define FR_COMMAND_ZIP_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), FR_TYPE_COMMAND_ZIP, FRCommandZipClass))
#define FR_IS_COMMAND_ZIP(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FR_TYPE_COMMAND_ZIP))
#define FR_IS_COMMAND_ZIP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), FR_TYPE_COMMAND_ZIP))
#define FR_COMMAND_ZIP_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), FR_TYPE_COMMAND_ZIP, FRCommandZipClass))

typedef struct _FRCommandZip       FRCommandZip;
typedef struct _FRCommandZipClass  FRCommandZipClass;

struct _FRCommandZip
{
	FRCommand  __parent;
	gboolean   is_empty;
};

struct _FRCommandZipClass
{
	FRCommandClass __parent_class;
};

GType        fr_command_zip_get_type        (void);
FRCommand*   fr_command_zip_new             (FRProcess *process,
					     const char *filename);

#endif /* FR_COMMAND_ZIP_H */
